@@ -63,5 +63,5 @@ class StorageMap(NamespacedResource, MTV):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update(self.map_to_dict)
